@@ -24,10 +24,12 @@ import uuid
 
 from flask import Flask, request, render_template, g
 
-_ENV_VAR = 'XS_AUTHSERVER_CONFIG'
-
-OLPC_XS_DB = '/home/idmgr/identity.db'
-DATABASE = os.path.abspath(os.path.join(os.path.dirname(__file__), 'test.db'))
+# Default config
+ENV_PREFIX = 'XS_AUTHSERVER'
+ENV_VARS = {
+    'OLPC_XS_DB': '/home/idmgr/identity.db',
+    'DATABASE': os.path.abspath(os.path.join(os.path.dirname(__file__), 'test.db')),
+}
 
 
 def connect_to_database(database):
@@ -43,12 +45,15 @@ def get_db():
 
 
 def init_db():
-    with app.app_context():
-        db = get_db()
-        with app.open_resource('schema.sql', mode='r') as f:
-            db.cursor().executescript(f.read())
-        db.commit()
-
+    try:
+        with app.app_context():
+            db = get_db()
+            with app.open_resource('schema.sql', mode='r') as f:
+                db.cursor().executescript(f.read())
+            db.commit()
+            return True
+    except sqlite3.OperationalError as err:
+        return False
 
 def get_olpc_xs_db():
     db = getattr(g, '_olpc_xs_db', None)
@@ -187,8 +192,11 @@ def sync_idmgr():
 
 app = Flask(__name__)
 
-app.config.from_object(__name__)
-app.config.from_envvar(_ENV_VAR, silent=True)
+# Config section
+for var in ENV_VARS:
+    env_var = ENV_PREFIX + '_' + var
+    value = os.environ.get(env_var) or ENV_VARS[var]
+    app.config[var] = value
 
 
 @app.teardown_appcontext
